@@ -60,7 +60,7 @@ class Canvas(object):
 
         self.__requester = Requester(base_url, access_token)
 
-    def clear_course_nicknames(self):
+    def clear_course_nicknames(self, **kwargs):
         """
         Remove all stored course nicknames.
 
@@ -72,10 +72,14 @@ class Canvas(object):
         :rtype: bool
         """
 
-        response = self.__requester.request("DELETE", "users/self/course_nicknames")
+        response = self.__requester.request(
+            "DELETE",
+            "users/self/course_nicknames",
+            _kwargs=combine_kwargs(**kwargs),
+        )
         return response.json().get("message") == "OK"
 
-    def conversations_batch_update(self, conversation_ids, event):
+    def conversations_batch_update(self, conversation_ids, event, **kwargs):
         """
 
         :calls: `PUT /api/v1/conversations \
@@ -99,34 +103,32 @@ class Canvas(object):
             "destroy",
         ]
 
-        try:
-            if event not in ALLOWED_EVENTS:
-                raise ValueError(
-                    "{} is not a valid action. Please use one of the following: {}".format(
-                        event, ",".join(ALLOWED_EVENTS)
-                    )
+        if event not in ALLOWED_EVENTS:
+            raise ValueError(
+                "{} is not a valid action. Please use one of the following: {}".format(
+                    event, ",".join(ALLOWED_EVENTS)
                 )
-
-            if len(conversation_ids) > 500:
-                raise ValueError(
-                    "You have requested {} updates, which exceeds the limit of 500".format(
-                        len(conversation_ids)
-                    )
-                )
-
-            response = self.__requester.request(
-                "PUT",
-                "conversations",
-                event=event,
-                **{"conversation_ids[]": conversation_ids}
             )
-            return_progress = Progress(self.__requester, response.json())
-            return return_progress
 
-        except ValueError as e:
-            return e
+        if len(conversation_ids) > 500:
+            raise ValueError(
+                "You have requested {} updates, which exceeds the limit of 500".format(
+                    len(conversation_ids)
+                )
+            )
 
-    def conversations_get_running_batches(self):
+        kwargs["conversation_ids"] = conversation_ids
+        kwargs["event"] = event
+
+        response = self.__requester.request(
+            "PUT",
+            "conversations",
+            _kwargs=combine_kwargs(**kwargs),
+        )
+        return_progress = Progress(self.__requester, response.json())
+        return return_progress
+
+    def conversations_get_running_batches(self, **kwargs):
         """
         Returns any currently running conversation batches for the current user.
         Conversation batches are created when a bulk private message is sent
@@ -139,11 +141,13 @@ class Canvas(object):
         :rtype: `dict`
         """
 
-        response = self.__requester.request("GET", "conversations/batches")
+        response = self.__requester.request(
+            "GET", "conversations/batches", _kwargs=combine_kwargs(**kwargs)
+        )
 
         return response.json()
 
-    def conversations_mark_all_as_read(self):
+    def conversations_mark_all_as_read(self, **kwargs):
         """
         Mark all conversations as read.
 
@@ -152,10 +156,12 @@ class Canvas(object):
 
         :rtype: `bool`
         """
-        response = self.__requester.request("POST", "conversations/mark_all_as_read")
+        response = self.__requester.request(
+            "POST", "conversations/mark_all_as_read", _kwargs=combine_kwargs(**kwargs)
+        )
         return response.json() == {}
 
-    def conversations_unread_count(self):
+    def conversations_unread_count(self, **kwargs):
         """
         Get the number of unread conversations for the current user
 
@@ -165,7 +171,9 @@ class Canvas(object):
         :returns: simple object with unread_count, example: {'unread_count': '7'}
         :rtype: `dict`
         """
-        response = self.__requester.request("GET", "conversations/unread_count")
+        response = self.__requester.request(
+            "GET", "conversations/unread_count", _kwargs=combine_kwargs(**kwargs)
+        )
 
         return response.json()
 
@@ -413,7 +421,7 @@ class Canvas(object):
             _kwargs=combine_kwargs(**kwargs),
         )
 
-    def get_activity_stream_summary(self):
+    def get_activity_stream_summary(self, **kwargs):
         """
         Return a summary of the current user's global activity stream.
 
@@ -422,21 +430,47 @@ class Canvas(object):
 
         :rtype: dict
         """
-        response = self.__requester.request("GET", "users/self/activity_stream/summary")
+        response = self.__requester.request(
+            "GET",
+            "users/self/activity_stream/summary",
+            _kwargs=combine_kwargs(**kwargs),
+        )
         return response.json()
 
-    def get_announcements(self, **kwargs):
+    def get_announcements(self, context_codes, **kwargs):
         """
         List announcements.
 
         :calls: `GET /api/v1/announcements \
         <https://canvas.instructure.com/doc/api/announcements.html#method.announcements_api.index>`_
 
+        :param context_codes: Course ID(s) or <Course> objects to request announcements from.
+        :type context_codes: list
+
         :rtype: :class:`canvasapi.paginated_list.PaginatedList` of
                 :class:`canvasapi.discussion_topic.DiscussionTopic`
         """
         from canvasapi.discussion_topic import DiscussionTopic
 
+        if type(context_codes) is not list or len(context_codes) == 0:
+            raise RequiredFieldMissing("context_codes need to be passed as a list")
+
+        if isinstance(context_codes[0], str) and "course_" in context_codes[0]:
+            # Legacy support for context codes passed as list of `course_123`-style strings
+            kwargs["context_codes"] = context_codes
+        else:
+            # The type of object in `context_codes` is taken care of by obj_or_id, extracting
+            # the course ID from a <Course> object or by returning plain strings.
+            course_ids = [
+                obj_or_id(course_id, "context_codes", (Course,))
+                for course_id in context_codes
+            ]
+
+            # Set the **kwargs object vaue so it can be combined with others passed by the user.
+            kwargs["context_codes"] = [
+                f"course_{course_id}" for course_id in course_ids
+            ]
+
         return PaginatedList(
             DiscussionTopic,
             self.__requester,
@@ -445,7 +479,7 @@ class Canvas(object):
             _kwargs=combine_kwargs(**kwargs),
         )
 
-    def get_appointment_group(self, appointment_group):
+    def get_appointment_group(self, appointment_group, **kwargs):
         """
         Return single Appointment Group by id
 
@@ -464,7 +498,9 @@ class Canvas(object):
         )
 
         response = self.__requester.request(
-            "GET", "appointment_groups/{}".format(appointment_group_id)
+            "GET",
+            "appointment_groups/{}".format(appointment_group_id),
+            _kwargs=combine_kwargs(**kwargs),
         )
         return AppointmentGroup(self.__requester, response.json())
 
@@ -488,7 +524,7 @@ class Canvas(object):
             _kwargs=combine_kwargs(**kwargs),
         )
 
-    def get_brand_variables(self):
+    def get_brand_variables(self, **kwargs):
         """
         Get account brand variables
 
@@ -498,10 +534,12 @@ class Canvas(object):
         :returns: JSON with brand variables for the account.
         :rtype: dict
         """
-        response = self.__requester.request("GET", "brand_variables")
+        response = self.__requester.request(
+            "GET", "brand_variables", _kwargs=combine_kwargs(**kwargs)
+        )
         return response.json()
 
-    def get_calendar_event(self, calendar_event):
+    def get_calendar_event(self, calendar_event, **kwargs):
         """
         Return single Calendar Event by id
 
@@ -520,7 +558,9 @@ class Canvas(object):
         )
 
         response = self.__requester.request(
-            "GET", "calendar_events/{}".format(calendar_event_id)
+            "GET",
+            "calendar_events/{}".format(calendar_event_id),
+            _kwargs=combine_kwargs(**kwargs),
         )
         return CalendarEvent(self.__requester, response.json())
 
@@ -552,7 +592,7 @@ class Canvas(object):
         <https://canvas.instructure.com/doc/api/comm_messages.html#method.comm_messages_api.index>`_
 
         :param user: The object or ID of the user.
-        :type user: :class: `canvasapi.user.User` or int
+        :type user: :class:`canvasapi.user.User` or int
 
         :returns: Paginated list containing messages sent to user
         :rtype: :class:`canvasapi.paginated_list.PaginatedList` of
@@ -640,7 +680,7 @@ class Canvas(object):
         )
         return Course(self.__requester, response.json())
 
-    def get_course_accounts(self):
+    def get_course_accounts(self, **kwargs):
         """
         List accounts that the current user can view through their
         admin course enrollments (Teacher, TA or designer enrollments).
@@ -654,9 +694,15 @@ class Canvas(object):
         :rtype: :class:`canvasapi.paginated_list.PaginatedList` of
             :class:`canvasapi.account.Account`
         """
-        return PaginatedList(Account, self.__requester, "GET", "course_accounts")
+        return PaginatedList(
+            Account,
+            self.__requester,
+            "GET",
+            "course_accounts",
+            _kwargs=combine_kwargs(**kwargs),
+        )
 
-    def get_course_nickname(self, course):
+    def get_course_nickname(self, course, **kwargs):
         """
         Return the nickname for the given course.
 
@@ -673,11 +719,13 @@ class Canvas(object):
         course_id = obj_or_id(course, "course", (Course,))
 
         response = self.__requester.request(
-            "GET", "users/self/course_nicknames/{}".format(course_id)
+            "GET",
+            "users/self/course_nicknames/{}".format(course_id),
+            _kwargs=combine_kwargs(**kwargs),
         )
         return CourseNickname(self.__requester, response.json())
 
-    def get_course_nicknames(self):
+    def get_course_nicknames(self, **kwargs):
         """
         Return all course nicknames set by the current account.
 
@@ -690,7 +738,11 @@ class Canvas(object):
         from canvasapi.course import CourseNickname
 
         return PaginatedList(
-            CourseNickname, self.__requester, "GET", "users/self/course_nicknames"
+            CourseNickname,
+            self.__requester,
+            "GET",
+            "users/self/course_nicknames",
+            _kwargs=combine_kwargs(**kwargs),
         )
 
     def get_courses(self, **kwargs):
@@ -708,6 +760,14 @@ class Canvas(object):
         )
 
     def get_current_user(self):
+        """
+        Return a details of the current user.
+
+        :calls: `GET /api/v1/users/:user_id \
+        <https://canvas.instructure.com/doc/api/users.html#method.current_user.show>`_
+
+        :rtype: :class:`canvasapi.current_user.CurrentUser`
+        """
         return CurrentUser(self.__requester)
 
     def get_epub_exports(self, **kwargs):
@@ -749,7 +809,7 @@ class Canvas(object):
         )
         return File(self.__requester, response.json())
 
-    def get_folder(self, folder):
+    def get_folder(self, folder, **kwargs):
         """
         Return the details for a folder
 
@@ -763,7 +823,9 @@ class Canvas(object):
         """
         folder_id = obj_or_id(folder, "folder", (Folder,))
 
-        response = self.__requester.request("GET", "folders/{}".format(folder_id))
+        response = self.__requester.request(
+            "GET", "folders/{}".format(folder_id), _kwargs=combine_kwargs(**kwargs)
+        )
         return Folder(self.__requester, response.json())
 
     def get_group(self, group, use_sis_id=False, **kwargs):
@@ -796,7 +858,7 @@ class Canvas(object):
         )
         return Group(self.__requester, response.json())
 
-    def get_group_category(self, category):
+    def get_group_category(self, category, **kwargs):
         """
         Get a single group category.
 
@@ -811,7 +873,9 @@ class Canvas(object):
         category_id = obj_or_id(category, "category", (GroupCategory,))
 
         response = self.__requester.request(
-            "GET", "group_categories/{}".format(category_id)
+            "GET",
+            "group_categories/{}".format(category_id),
+            _kwargs=combine_kwargs(**kwargs),
         )
         return GroupCategory(self.__requester, response.json())
 
@@ -842,7 +906,7 @@ class Canvas(object):
             _kwargs=combine_kwargs(**kwargs),
         )
 
-    def get_outcome(self, outcome):
+    def get_outcome(self, outcome, **kwargs):
         """
         Returns the details of the outcome with the given id.
 
@@ -858,10 +922,12 @@ class Canvas(object):
         from canvasapi.outcome import Outcome
 
         outcome_id = obj_or_id(outcome, "outcome", (Outcome,))
-        response = self.__requester.request("GET", "outcomes/{}".format(outcome_id))
+        response = self.__requester.request(
+            "GET", "outcomes/{}".format(outcome_id), _kwargs=combine_kwargs(**kwargs)
+        )
         return Outcome(self.__requester, response.json())
 
-    def get_outcome_group(self, group):
+    def get_outcome_group(self, group, **kwargs):
         """
         Returns the details of the Outcome Group with the given id.
 
@@ -879,7 +945,9 @@ class Canvas(object):
         outcome_group_id = obj_or_id(group, "group", (OutcomeGroup,))
 
         response = self.__requester.request(
-            "GET", "global/outcome_groups/{}".format(outcome_group_id)
+            "GET",
+            "global/outcome_groups/{}".format(outcome_group_id),
+            _kwargs=combine_kwargs(**kwargs),
         )
 
         return OutcomeGroup(self.__requester, response.json())
@@ -1049,7 +1117,7 @@ class Canvas(object):
         )
         return Progress(self.__requester, response.json())
 
-    def get_root_outcome_group(self):
+    def get_root_outcome_group(self, **kwargs):
         """
         Redirect to root outcome group for context
 
@@ -1061,7 +1129,9 @@ class Canvas(object):
         """
         from canvasapi.outcome import OutcomeGroup
 
-        response = self.__requester.request("GET", "global/root_outcome_group")
+        response = self.__requester.request(
+            "GET", "global/root_outcome_group", _kwargs=combine_kwargs(**kwargs)
+        )
         return OutcomeGroup(self.__requester, response.json())
 
     def get_section(self, section, use_sis_id=False, **kwargs):
@@ -1091,7 +1161,7 @@ class Canvas(object):
         )
         return Section(self.__requester, response.json())
 
-    def get_todo_items(self):
+    def get_todo_items(self, **kwargs):
         """
         Return the current user's list of todo items, as seen on the user dashboard.
 
@@ -1100,10 +1170,12 @@ class Canvas(object):
 
         :rtype: dict
         """
-        response = self.__requester.request("GET", "users/self/todo")
+        response = self.__requester.request(
+            "GET", "users/self/todo", _kwargs=combine_kwargs(**kwargs)
+        )
         return response.json()
 
-    def get_upcoming_events(self):
+    def get_upcoming_events(self, **kwargs):
         """
         Return the current user's upcoming events, i.e. the same things shown
         in the dashboard 'Coming Up' sidebar.
@@ -1113,7 +1185,9 @@ class Canvas(object):
 
         :rtype: dict
         """
-        response = self.__requester.request("GET", "users/self/upcoming_events")
+        response = self.__requester.request(
+            "GET", "users/self/upcoming_events", _kwargs=combine_kwargs(**kwargs)
+        )
         return response.json()
 
     def get_user(self, user, id_type=None, **kwargs):
@@ -1284,7 +1358,7 @@ class Canvas(object):
         )
         return response.json()
 
-    def set_course_nickname(self, course, nickname):
+    def set_course_nickname(self, course, nickname, **kwargs):
         """
         Set a nickname for the given course. This will replace the
         course's name in the output of subsequent API calls, as
@@ -1304,7 +1378,11 @@ class Canvas(object):
 
         course_id = obj_or_id(course, "course", (Course,))
 
+        kwargs["nickname"] = nickname
+
         response = self.__requester.request(
-            "PUT", "users/self/course_nicknames/{}".format(course_id), nickname=nickname
+            "PUT",
+            "users/self/course_nicknames/{}".format(course_id),
+            _kwargs=combine_kwargs(**kwargs),
         )
         return CourseNickname(self.__requester, response.json())
