@@ -3,8 +3,9 @@ from canvasapi.canvas_object import CanvasObject
 from canvasapi.communication_channel import CommunicationChannel
 from canvasapi.feature import Feature, FeatureFlag
 from canvasapi.folder import Folder
-from canvasapi.paginated_list import PaginatedList
 from canvasapi.license import License
+from canvasapi.paginated_list import PaginatedList
+from canvasapi.pairing_code import PairingCode
 from canvasapi.upload import Uploader
 from canvasapi.usage_rights import UsageRights
 from canvasapi.util import combine_kwargs, obj_or_id, obj_or_str
@@ -14,7 +15,7 @@ class User(CanvasObject):
     def __str__(self):
         return "{} ({})".format(self.name, self.id)
 
-    def add_observee(self, observee_id):
+    def add_observee(self, observee_id, **kwargs):
         """
         Registers a user as being observed by the given user.
 
@@ -27,7 +28,9 @@ class User(CanvasObject):
         """
 
         response = self._requester.request(
-            "PUT", "users/{}/observees/{}".format(self.id, observee_id)
+            "PUT",
+            "users/{}/observees/{}".format(self.id, observee_id),
+            _kwargs=combine_kwargs(**kwargs),
         )
         return User(self._requester, response.json())
 
@@ -116,6 +119,24 @@ class User(CanvasObject):
         )
         return Folder(self._requester, response.json())
 
+    def create_pairing_code(self, **kwargs):
+        """
+        Create a pairing code for this user.
+
+        :calls: `POST /api/v1/users/:user_id/observer_pairing_codes \
+            <https://canvas.instructure.com/doc/api/user_observees.html#method.observer_pairing_codes_api.create>`_
+
+        :rtype: :class:`canvasapi.pairing_code.PairingCode`
+        """
+
+        response = self._requester.request(
+            "POST",
+            "users/{}/observer_pairing_codes".format(self.id),
+            _kwargs=combine_kwargs(**kwargs),
+        )
+
+        return PairingCode(self._requester, response.json())
+
     def edit(self, **kwargs):
         """
         Modify this user's information.
@@ -201,7 +222,7 @@ class User(CanvasObject):
             _kwargs=combine_kwargs(**kwargs),
         )
 
-    def get_avatars(self):
+    def get_avatars(self, **kwargs):
         """
         Retrieve the possible user avatar options that can be set with the user update endpoint.
 
@@ -214,7 +235,11 @@ class User(CanvasObject):
         from canvasapi.avatar import Avatar
 
         return PaginatedList(
-            Avatar, self._requester, "GET", "users/{}/avatars".format(self.id)
+            Avatar,
+            self._requester,
+            "GET",
+            "users/{}/avatars".format(self.id),
+            _kwargs=combine_kwargs(**kwargs),
         )
 
     def get_calendar_events_for_user(self, **kwargs):
@@ -256,7 +281,7 @@ class User(CanvasObject):
             _kwargs=combine_kwargs(**kwargs),
         )
 
-    def get_color(self, asset_string):
+    def get_color(self, asset_string, **kwargs):
         """
         Return the custom colors that have been saved by this user for a given context.
 
@@ -270,11 +295,13 @@ class User(CanvasObject):
         :rtype: dict
         """
         response = self._requester.request(
-            "GET", "users/{}/colors/{}".format(self.id, asset_string)
+            "GET",
+            "users/{}/colors/{}".format(self.id, asset_string),
+            _kwargs=combine_kwargs(**kwargs),
         )
         return response.json()
 
-    def get_colors(self):
+    def get_colors(self, **kwargs):
         """
         Return all custom colors that have been saved by this user.
 
@@ -283,7 +310,11 @@ class User(CanvasObject):
 
         :rtype: dict
         """
-        response = self._requester.request("GET", "users/{}/colors".format(self.id))
+        response = self._requester.request(
+            "GET",
+            "users/{}/colors".format(self.id),
+            _kwargs=combine_kwargs(**kwargs),
+        )
         return response.json()
 
     def get_communication_channels(self, **kwargs):
@@ -541,7 +572,7 @@ class User(CanvasObject):
             _kwargs=combine_kwargs(**kwargs),
         )
 
-    def get_folder(self, folder):
+    def get_folder(self, folder, **kwargs):
         """
         Returns the details for a user's folder
 
@@ -558,7 +589,9 @@ class User(CanvasObject):
         folder_id = obj_or_id(folder, "folder", (Folder,))
 
         response = self._requester.request(
-            "GET", "users/{}/folders/{}".format(self.id, folder_id)
+            "GET",
+            "users/{}/folders/{}".format(self.id, folder_id),
+            _kwargs=combine_kwargs(**kwargs),
         )
         return Folder(self._requester, response.json())
 
@@ -621,7 +654,7 @@ class User(CanvasObject):
             _kwargs=combine_kwargs(**kwargs),
         )
 
-    def get_missing_submissions(self):
+    def get_missing_submissions(self, **kwargs):
         """
         Retrieve all past-due assignments for which the student does not
         have a submission.
@@ -639,6 +672,7 @@ class User(CanvasObject):
             self._requester,
             "GET",
             "users/{}/missing_submissions".format(self.id),
+            _kwargs=combine_kwargs(**kwargs),
         )
 
     def get_observees(self, **kwargs):
@@ -733,7 +767,7 @@ class User(CanvasObject):
             _kwargs=combine_kwargs(**kwargs),
         )
 
-    def merge_into(self, destination_user):
+    def merge_into(self, destination_user, **kwargs):
         """
         Merge this user into another user.
 
@@ -748,12 +782,14 @@ class User(CanvasObject):
         dest_user_id = obj_or_id(destination_user, "destination_user", (User,))
 
         response = self._requester.request(
-            "PUT", "users/{}/merge_into/{}".format(self.id, dest_user_id)
+            "PUT",
+            "users/{}/merge_into/{}".format(self.id, dest_user_id),
+            _kwargs=combine_kwargs(**kwargs),
         )
         super(User, self).set_attributes(response.json())
         return self
 
-    def remove_observee(self, observee_id):
+    def remove_observee(self, observee_id, **kwargs):
         """
         Unregisters a user as being observed by the given user.
 
@@ -766,7 +802,9 @@ class User(CanvasObject):
         """
 
         response = self._requester.request(
-            "DELETE", "users/{}/observees/{}".format(self.id, observee_id)
+            "DELETE",
+            "users/{}/observees/{}".format(self.id, observee_id),
+            _kwargs=combine_kwargs(**kwargs),
         )
         return User(self._requester, response.json())
 
@@ -788,6 +826,39 @@ class User(CanvasObject):
 
         return response.json()
 
+    def resolve_path(self, full_path=None, **kwargs):
+        """
+        Returns the paginated list of all of the folders in the given
+        path starting at the user root folder. Returns root folder if called
+        with no arguments.
+
+        :calls: `GET /api/v1/users/:user_id/folders/by_path/*full_path \
+        <https://canvas.instructure.com/doc/api/files.html#method.folders.resolve_path>`_
+
+        :param full_path: Full path to resolve, relative to user root.
+        :type full_path: string
+
+        :rtype: :class:`canvasapi.paginated_list.PaginatedList` of
+            :class:`canvasapi.folder.Folder`
+        """
+
+        if full_path:
+            return PaginatedList(
+                Folder,
+                self._requester,
+                "GET",
+                "users/{0}/folders/by_path/{1}".format(self.id, full_path),
+                _kwargs=combine_kwargs(**kwargs),
+            )
+        else:
+            return PaginatedList(
+                Folder,
+                self._requester,
+                "GET",
+                "users/{0}/folders/by_path".format(self.id),
+                _kwargs=combine_kwargs(**kwargs),
+            )
+
     def set_usage_rights(self, **kwargs):
         """
         Changes the usage rights for specified files that are under the user scope
@@ -806,7 +877,7 @@ class User(CanvasObject):
 
         return UsageRights(self._requester, response.json())
 
-    def show_observee(self, observee_id):
+    def show_observee(self, observee_id, **kwargs):
         """
         Gets information about an observed user.
 
@@ -819,11 +890,13 @@ class User(CanvasObject):
         """
 
         response = self._requester.request(
-            "GET", "users/{}/observees/{}".format(self.id, observee_id)
+            "GET",
+            "users/{}/observees/{}".format(self.id, observee_id),
+            _kwargs=combine_kwargs(**kwargs),
         )
         return User(self._requester, response.json())
 
-    def update_color(self, asset_string, hexcode):
+    def update_color(self, asset_string, hexcode, **kwargs):
         """
         Update a custom color for this user for a given context.
 
@@ -841,8 +914,11 @@ class User(CanvasObject):
         :type hexcode: str
         :rtype: dict
         """
+        kwargs["hexcode"] = hexcode
         response = self._requester.request(
-            "PUT", "users/{}/colors/{}".format(self.id, asset_string), hexcode=hexcode
+            "PUT",
+            "users/{}/colors/{}".format(self.id, asset_string),
+            _kwargs=combine_kwargs(**kwargs),
         )
         return response.json()
 
